@@ -201,28 +201,28 @@ endorse <- function(Y,
   }
 
   if (update) {
-    beta.start <- update.start$beta.restart
+    beta.start <- update.start$beta.start
     
     tau.start <- matrix(-99, nrow = J, ncol = max.L)
     for (j in 1:J) {
-      tau.start[j, 1:(max.L - 1)] <- update.start$tau.restart[((max.L - 1) *
+      tau.start[j, 1:(max.L - 1)] <- update.start$tau.start[((max.L - 1) *
                                                              (j - 1) + 1):((max.L -
                                                                             1) * j)]
       tau.start[j, L[j]] <- max(tau.start[j, ]) + 1000
     }
 
-    x.start <- update.start$x.restart
-    s.start <- update.start$s.restart
-    lambda.start <- update.start$lambda.restart
-    omega2.start <- update.start$omega2.restart
-    theta.start <- update.start$theta.restart
-    phi2.start <- update.start$phi2.restart
-    if (covariates) delta.start <- update.start$delta.restart
+    x.start <- update.start$x.start
+    s.start <- update.start$s.start
+    lambda.start <- update.start$lambda.start
+    omega2.start <- update.start$omega2.start
+    theta.start <- update.start$theta.start
+    phi2.start <- update.start$phi2.start
+    if (covariates) delta.start <- update.start$delta.start
     if (hierarchical) {
-      kappa.start <- update.start$kappa.restart
-      psi2.start <- update.start$psi2.restart
-      zeta.start <- update.start$zeta.restart
-      rho2.start <- update.start$rho2.restart
+      kappa.start <- update.start$kappa.start
+      psi2.start <- update.start$psi2.start
+      zeta.start <- update.start$zeta.start
+      rho2.start <- update.start$rho2.start
     }
 
     .Random.seed <- update.start$seed
@@ -540,7 +540,7 @@ endorse <- function(Y,
 
   printout <- floor( (MCMC - burn) / thin )
 
-  temp <- .C("R2endorse",
+  temp <- .Call("R2endorse",
              as.integer(response),
              as.integer(endorse),
              as.double(cov.mat),
@@ -608,7 +608,8 @@ endorse <- function(Y,
 	     sig2Last = double(1),
              rho2Last = double(1),
              accept.ratio = double(J),
-             package = "endorse")
+             PACKAGE = "endorse"
+             )
 
   seedStore <- .Random.seed
 
@@ -633,20 +634,20 @@ endorse <- function(Y,
               rho2 = if (hierarchical) matrix(as.double(temp$rho2Store), byrow = TRUE, ncol = 1, nrow = printout) else NULL,
               accept.ratio = if (mh) as.double(temp$accept.ratio) else NULL,
               seed = if (seed.store) seedStore else NULL,
-              beta.restart = if (seed.store) matrix(as.double(temp$betaLast), nrow = J, ncol = 2, byrow = TRUE) else NULL,
-              tau.restart = if (seed.store) as.double(temp$tauLast) else NULL,
-              x.restart = if (seed.store) as.double(temp$xLast) else NULL,
-              s.restart = if (seed.store) matrix(as.double(temp$sLast), nrow = N, ncol = J, byrow = TRUE) else NULL,
-              lambda.restart = if (seed.store) as.double(temp$lambdaLast) else NULL,
-              theta.restart = if (seed.store & !identical.lambda) as.double(temp$thetaLast) else NULL,
-              kappa.restart = if (seed.store & hierarchical) as.double(temp$kappaLast) else NULL,
-              delta.restart = if (seed.store & (covariates | hierarchical)) as.double(temp$deltaLast) else NULL,
-              zeta.restart = if (seed.store & hierarchical) as.double(temp$zetaLast) else NULL,
-              omega2.restart = if (seed.store) as.double(temp$omega2Last) else NULL,
-              phi2.restart = if (seed.store & !identical.lambda) as.double(temp$phi2Last) else NULL,
-              psi2.restart = if (seed.store & hierarchical) as.double(temp$psi2Last) else NULL,
-	      sig2.restart = if (seed.store & (covariates | hierarchical)) as.double(temp$sig2.start) else NULL,
-              rho2.restart = if (seed.store & hierarchical) as.double(temp$rho2Last) else NULL,
+              beta.start = if (seed.store) matrix(as.double(temp$betaLast), nrow = J, ncol = 2, byrow = TRUE) else NULL,
+              tau.start = if (seed.store) as.double(temp$tauLast) else NULL,
+              x.start = if (seed.store) as.double(temp$xLast) else NULL,
+              s.start = if (seed.store) matrix(as.double(temp$sLast), nrow = N, ncol = J, byrow = TRUE) else NULL,
+              lambda.start = if (seed.store) as.double(temp$lambdaLast) else NULL,
+              theta.start = if (seed.store & !identical.lambda) as.double(temp$thetaLast) else NULL,
+              kappa.start = if (seed.store & hierarchical) as.double(temp$kappaLast) else NULL,
+              delta.start = if (seed.store & (covariates | hierarchical)) as.double(temp$deltaLast) else NULL,
+              zeta.start = if (seed.store & hierarchical) as.double(temp$zetaLast) else NULL,
+              omega2.start = if (seed.store) as.double(temp$omega2Last) else NULL,
+              phi2.start = if (seed.store & !identical.lambda) as.double(temp$phi2Last) else NULL,
+              psi2.start = if (seed.store & hierarchical) as.double(temp$psi2Last) else NULL,
+	      sig2.start = if (seed.store & (covariates | hierarchical)) as.double(temp$sig2.start) else NULL,
+              rho2.start = if (seed.store & hierarchical) as.double(temp$rho2Last) else NULL,
               village.indicator = village + 1,
               model.matrix.indiv = cov.mat,
               formula.indiv = formula.indiv,
